@@ -31,6 +31,7 @@ from norm1 import norm1
 from norm2 import norm2
 from norm_inf import normInf
 from norm_nuc import normNuc
+from mixed_norm import mixed_norm
 from quad_form import quad_form
 from quad_over_lin import quad_over_lin
 from sigma_max import sigma_max
@@ -44,6 +45,7 @@ from affine.mul_elemwise import mul_elemwise
 from affine.reshape import reshape
 from affine.sum_entries import sum_entries
 from affine.trace import trace
+from affine.vec import vec
 from affine.vstack import vstack
 
 from elementwise.abs import abs
