@@ -620,7 +620,10 @@ class Problem(u.Canonical):
         # Always do one step of iterative refinement after solving KKT system.
         cvxopt.solvers.options['refinement'] = 1
 
-        # Apply any user-specific options
+        # Apply any user-specific options.
+        # Rename max_iters to maxiters.
+        if "max_iters" in opts:
+            opts["maxiters"] = opts["max_iters"]
         for key, value in opts.items():
             cvxopt.solvers.options[key] = value
 
@@ -728,8 +731,9 @@ class Problem(u.Canonical):
                                            var_offsets, x_length)
         obj_offset = prob_data[1]
         # Set the options to be VERBOSE plus any user-specific options.
-        opts = dict({ "VERBOSE": verbose }.items() + opts.items())
-        use_indirect = opts["USE_INDIRECT"] if "USE_INDIRECT" in opts else False
+        opts = {k.upper():v for k, v in opts.items()}
+        opts["VERBOSE"] = verbose
+        use_indirect = opts.get("USE_INDIRECT", False)
         results = scs.solve(*prob_data[0], opts=opts, USE_INDIRECT = use_indirect)
         status = s.SOLVER_STATUS[s.SCS][results["info"]["status"]]
         if status in s.SOLUTION_PRESENT:
@@ -755,9 +759,9 @@ class Problem(u.Canonical):
         for constr in self.constraints:
             constr.save_value(None)
         # Set the problem value.
-        if status == s.INFEASIBLE:
+        if status in [s.INFEASIBLE, s.INFEASIBLE_INACCURATE]:
             self._value = self.objective._primal_to_result(np.inf)
-        elif status == s.UNBOUNDED:
+        elif status in [s.UNBOUNDED, s.UNBOUNDED_INACCURATE]:
             self._value = self.objective._primal_to_result(-np.inf)
 
     def _get_var_offsets(self, objective, constraints, nonlinear=None):
@@ -987,7 +991,15 @@ class Problem(u.Canonical):
         return F
 
     def __str__(self):
-        return repr(self)
+        if len(self.constraints) == 0:
+            return str(self.objective)
+        else:
+            subject_to = "subject to "
+            lines = [str(self.objective),
+                     subject_to + str(self.constraints[0])]
+            for constr in self.constraints[1:]:
+                lines += [len(subject_to)*" " + str(constr)]
+            return '\n'.join(lines)
 
     def __repr__(self):
         return "Problem(%s, %s)" % (repr(self.objective),
